@@ -1,9 +1,7 @@
 
 /*
- *  Time-stamp:        "2011-05-15 11:51:46 bkorb"
- *
  *  This file is part of Complexity.
- *  Complexity Copyright (c) 2011 by Bruce Korb - all rights reserved
+ *  Complexity Copyright (c) 2011-2014 by Bruce Korb - all rights reserved
  *
  *  Complexity is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -41,6 +39,7 @@ static int     high_score     = 0;
 static char const head_fmt[] =     "Complexity Scores\n"
     "Score | ln-ct | nc-lns| file-name(line): proc-name\n";
 static char const line_fmt[] =     "%5d  %6d  %6d   %s(%d): %s\n";
+static char const lnct_fmt[] =     "total nc-lns %8d\n";
 static char const bad_line_fmt[] = "***** %6d %6d %s(%d): %s\n";
 static char const nomem_fmt[] =    "could not allocate %d bytes\n";
 
@@ -149,17 +148,17 @@ print_histogram(void)
         fwrite(hsthdr, sizeof(hsthdr) - 1, 1, stdout);
     }
 
-    int    min_score  = 0;
-    int    score_inc  = 10;
-    int    hi_score   = min_score + score_inc - 1;
-    bool_t skipping   = true;
-    bool_t first_line = true;
+    int  min_score  = 0;
+    int  score_inc  = 10;
+    int  hi_score   = min_score + score_inc - 1;
+    bool skipping   = true;
+    bool first_line = true;
 
     for (int ix = 0;
          ix < score_ix_lim;
          ix++, min_score = hi_score + 1, hi_score += score_inc) {
-        int    ct     = lines_scoring[ix];
-        bool_t put_nl = false;
+        int  ct     = lines_scoring[ix];
+        bool put_nl = false;
 
         switch (min_score) {
         case 90:  score_inc = 100;  put_nl = true; break;
@@ -289,7 +288,9 @@ do_summary(complexity_exit_code_t exit_code)
     if (HAVE_OPT(HISTOGRAM)) {
         print_histogram();
         print_stats();
-    }
+
+    } else if (! HAVE_OPT(NO_HEADER))
+        printf(lnct_fmt, ttl_line_ct);
 }
 
 static FILE *
@@ -355,7 +356,7 @@ popen_unifdef(char const * fname)
     }
 }
 
-static bool_t
+static bool
 load_file(fstate_t * fs)
 {
     unsigned long const pgsz = sysconf(_SC_PAGE_SIZE);
@@ -412,7 +413,7 @@ load_file(fstate_t * fs)
     return true;
 }
 
-static bool_t
+static bool
 add_score(state_t * pstate)
 {
     if (threshold > pstate->score)
